#!/usr/bin/env python3
#============================================================================
#
# NAME
#
#     plotRunningTime.py
#
# DESCRIPTION
#
#     Primitive polynomial running time plot in Python using Sympy and Numpy.
#
# USAGE
#
#     Collect data using the script 
#
#         runningTime.sh
#
#     Copy the times to this script.
#
# NOTES
#
#     numpy:                            http://www.numpy.org
#     matplotlib                        https://matplotlib.org
#     Python interpreter:               http://www.python.org
#     Python tutorial and reference:    htttp://docs.python.org/lib/lib.html
#
# LEGAL
#
#     Primpoly Version 16.2 - A Program for Computing Primitive Polynomials.
#     Copyright (C) 1999-2024 by Sean Erik O'Connor.  All Rights Reserved.
#
#     This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <http://www.gnu.org/licenses/>.
#    
#     The author's address is seanerikoconnor!AT!gmail!DOT!com
#     with the !DOT! replaced by . and the !AT! replaced by @
#
#============================================================================

import sys
import math
import numpy
import pylab
from numpy import *
from pylab import *

print( "Running Python Version {0:d}.{1:d}.{2:d}".format( sys.version_info[ 0 ], sys.version_info[ 1 ], sys.version_info[ 2 ] ) )

# Running time in seconds vs polynomial degree for mod 2 primitive polynomial finding.
degree                     = array( [     2,    10,    30,    50,    70,    90,   100,   120,   140,   145,   150,   160,    180,   200,    202,    210,    300 ])
runningTimeSecondsMacIntel = array( [ 1.730, 1.800, 1.821, 1.862, 1.875, 2.038, 3.622, 3.913, 5.824, 3.310, 4.753, 2.937, 13.178, 4.969, 10.252, 31.950, 24.502 ])
runningTimeSecondsMacArm   = array( [ 0.499, 0.476, 0.482, 0.490, 0.527, 0.594, 1.471, 1.561, 2.538, 1.260, 2.151, 1.150,  6.596, 2.051,  4.893, 15.878, 12.827 ])
runningTimeSecondsPC      = array( [ 0.286, 0.281, 0.292, 0.314, 0.378, 0.506, 2.180, 2.361, 4.246, 1.805, 3.528, 1.587, 12.094, 3.260,  8.453, 28.682, 23.932 ])
pylab.figure('Primpoly Running Time')
pylab.title('Running Time vs Degree for Mod 2 Primitive Polynomials') 
pylab.xlabel('Polynomial Degree') 
pylab.ylabel('Running Time, Seconds') 
pylab.semilogy()
pylab.plot( degree, runningTimeSecondsMacIntel )
pylab.plot( degree, runningTimeSecondsMacArm  )
pylab.plot( degree, runningTimeSecondsPC  )
pylab.legend(('MacBook Pro Mid-2015 Intel macOS', 'MacBook Pro 2021 Apple M1 Max macOS', 'CyberPowerPC 2019 Series C Ubuntu/Linux'))
pylab.show()


